Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(753)

Unified Diff: components/webdata/encryptor/ie7_password.h

Issue 26465006: Fix IE password import (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/webdata/encryptor/ie7_password.h
diff --git a/components/webdata/encryptor/ie7_password.h b/components/webdata/encryptor/ie7_password.h
index 458426640d8b8350be1e7e1d73fabb3447ee145d..686cc90689cf72fb466d88c2fd8dbea7826a62c5 100644
--- a/components/webdata/encryptor/ie7_password.h
+++ b/components/webdata/encryptor/ie7_password.h
@@ -27,16 +27,23 @@ struct IE7PasswordInfo {
namespace ie7_password {
-// Parses a data structure to find the password and the username.
+struct DecryptedCredentials {
+ DecryptedCredentials();
Lei Zhang 2013/10/08 17:49:46 nit: we generally don't bother with ctor/dtors for
+ ~DecryptedCredentials();
+
+ std::wstring username;
Lei Zhang 2013/10/08 17:49:46 There exists a presubmit check to prevent std::wst
+ std::wstring password;
+};
+
+// Parses a data structure to find passwords and usernames.
Lei Zhang 2013/10/08 17:49:46 Can you mention the format of |data| and mention |
bool GetUserPassFromData(const std::vector<unsigned char>& data,
- std::wstring* username,
- std::wstring* password);
+ std::vector<DecryptedCredentials>* credentials);
-// Decrypts the username and password for a given data vector using the url as
+// Decrypts usernames and passwords for a given data vector using the url as
// the key.
-bool DecryptPassword(const std::wstring& url,
- const std::vector<unsigned char>& data,
- std::wstring* username, std::wstring* password);
+bool DecryptPasswords(const std::wstring& url,
+ const std::vector<unsigned char>& data,
+ std::vector<DecryptedCredentials>* credentials);
// Returns the hash of a url.
std::wstring GetUrlHash(const std::wstring& url);

Powered by Google App Engine
This is Rietveld 408576698